@@ -14,11 +14,11 @@ LocalTest - Test functions for L<Audit::DBI>.
 
 =head1 VERSION
 
-Version 1.7.0
+Version 1.7.1
 
 =cut
 
-our $VERSION = '1.7.0';
+our $VERSION = '1.7.1';
 
 
 =head1 SYNOPSIS
@@ -100,9 +100,9 @@ L<http://annocpan.org/dist/Audit-DBI>
 
 L<http://cpanratings.perl.org/d/Audit-DBI>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Audit-DBI/>
+L<https://metacpan.org/release/Audit-DBI>
 
 =back
 
